@@ -54,8 +54,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.5m',
  'COREPYTHONPATH': ':plat-linux',
- 'COVERAGE_INFO': '/build/python/src/Python-3.5.0/coverage.info',
- 'COVERAGE_REPORT': '/build/python/src/Python-3.5.0/lcov-report',
+ 'COVERAGE_INFO': '/build/python/src/Python-3.5.1/coverage.info',
+ 'COVERAGE_REPORT': '/build/python/src/Python-3.5.1/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -IInclude -I./Include -D_FORTIFY_SOURCE=2 '
@@ -209,7 +209,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_GETPID': 1,
  'HAVE_GETPRIORITY': 1,
  'HAVE_GETPWENT': 1,
- 'HAVE_GETRANDOM_SYSCALL': 1,
+ 'HAVE_GETRANDOM': 0,
+ 'HAVE_GETRANDOM_SYSCALL': 0,
  'HAVE_GETRESGID': 1,
  'HAVE_GETRESUID': 1,
  'HAVE_GETSID': 1,
@@ -508,6 +509,9 @@ build_time_vars = {'ABIFLAGS': 'm',
  'LINKCC': 'gcc -pthread',
  'LINKFORSHARED': '-Xlinker -export-dynamic',
  'LIPO_32BIT_FLAGS': '',
+ 'LLVM_PROF_ERR': 'no',
+ 'LLVM_PROF_FILE': '',
+ 'LLVM_PROF_MERGER': 'true',
  'LN': 'ln',
  'LOCALMODLIBS': '',
  'LOG1P_DROPS_ZERO_SIGN': 0,
@@ -565,11 +569,13 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PGENOBJS': '\\ \\',
  'PGENSRCS': '\\ \\',
  'PGOBJS': '\\',
+ 'PGO_PROF_GEN_FLAG': '-fprofile-generate',
+ 'PGO_PROF_USE_FLAG': '-fprofile-use -fprofile-correction',
  'PGSRCS': '\\',
  'PLATDIR': 'plat-linux',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
- 'PROFILE_TASK': './Tools/pybench/pybench.py -n 2 --with-gc --with-syscheck',
+ 'PROFILE_TASK': '-m test.regrtest --pgo',
  'PSRCS': '\\',
  'PTHREAD_SYSTEM_SCHED_SUPPORTED': 1,
  'PURIFY': '',
@@ -617,7 +623,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python/src/Python-3.5.0',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python/src/Python-3.5.1',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '',
@@ -659,9 +665,9 @@ build_time_vars = {'ABIFLAGS': 'm',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python/src/Python-3.5.0 ./python',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python/src/Python-3.5.1 ./python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python/src/Python-3.5.0 ./python '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python/src/Python-3.5.1 ./python '
                './Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 3600,
  'THREADOBJ': 'Python/thread.o',
@@ -686,8 +692,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/build/python/src/Python-3.5.0',
- 'abs_srcdir': '/build/python/src/Python-3.5.0',
+ 'abs_builddir': '/build/python/src/Python-3.5.1',
+ 'abs_srcdir': '/build/python/src/Python-3.5.1',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
